@@ -157,6 +157,8 @@ import jsii
 import publication
 import typing_extensions
 
+from typeguard import check_type
+
 from ._jsii import *
 
 import aws_cdk.aws_iam
@@ -175,10 +177,10 @@ class IotToS3(
         scope: aws_cdk.core.Construct,
         id: builtins.str,
         *,
-        iot_topic_rule_props: aws_cdk.aws_iot.CfnTopicRuleProps,
-        bucket_props: typing.Optional[aws_cdk.aws_s3.BucketProps] = None,
+        iot_topic_rule_props: typing.Union[aws_cdk.aws_iot.CfnTopicRuleProps, typing.Dict[str, typing.Any]],
+        bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
         existing_bucket_interface: typing.Optional[aws_cdk.aws_s3.IBucket] = None,
-        logging_bucket_props: typing.Optional[aws_cdk.aws_s3.BucketProps] = None,
+        logging_bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
         log_s3_access_logs: typing.Optional[builtins.bool] = None,
         s3_key: typing.Optional[builtins.str] = None,
     ) -> None:
@@ -195,6 +197,10 @@ class IotToS3(
         :access: public
         :summary: Constructs a new instance of the IotToSqs class.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(IotToS3.__init__)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = IotToS3Props(
             iot_topic_rule_props=iot_topic_rule_props,
             bucket_props=bucket_props,
@@ -248,10 +254,10 @@ class IotToS3Props:
     def __init__(
         self,
         *,
-        iot_topic_rule_props: aws_cdk.aws_iot.CfnTopicRuleProps,
-        bucket_props: typing.Optional[aws_cdk.aws_s3.BucketProps] = None,
+        iot_topic_rule_props: typing.Union[aws_cdk.aws_iot.CfnTopicRuleProps, typing.Dict[str, typing.Any]],
+        bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
         existing_bucket_interface: typing.Optional[aws_cdk.aws_s3.IBucket] = None,
-        logging_bucket_props: typing.Optional[aws_cdk.aws_s3.BucketProps] = None,
+        logging_bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
         log_s3_access_logs: typing.Optional[builtins.bool] = None,
         s3_key: typing.Optional[builtins.str] = None,
     ) -> None:
@@ -271,6 +277,14 @@ class IotToS3Props:
             bucket_props = aws_cdk.aws_s3.BucketProps(**bucket_props)
         if isinstance(logging_bucket_props, dict):
             logging_bucket_props = aws_cdk.aws_s3.BucketProps(**logging_bucket_props)
+        if __debug__:
+            type_hints = typing.get_type_hints(IotToS3Props.__init__)
+            check_type(argname="argument iot_topic_rule_props", value=iot_topic_rule_props, expected_type=type_hints["iot_topic_rule_props"])
+            check_type(argname="argument bucket_props", value=bucket_props, expected_type=type_hints["bucket_props"])
+            check_type(argname="argument existing_bucket_interface", value=existing_bucket_interface, expected_type=type_hints["existing_bucket_interface"])
+            check_type(argname="argument logging_bucket_props", value=logging_bucket_props, expected_type=type_hints["logging_bucket_props"])
+            check_type(argname="argument log_s3_access_logs", value=log_s3_access_logs, expected_type=type_hints["log_s3_access_logs"])
+            check_type(argname="argument s3_key", value=s3_key, expected_type=type_hints["s3_key"])
         self._values: typing.Dict[str, typing.Any] = {
             "iot_topic_rule_props": iot_topic_rule_props,
         }
